
![Package Version](https://img.shields.io/badge/v1.0.3-blue)  

[![Publish Python 🐍 distribution 📦 to PyPI](https://github.com/p0lygun/vibhakar/actions/workflows/build-and-publish.yaml/badge.svg)](https://github.com/p0lygun/vibhakar/actions/workflows/build-and-publish.yaml)

A python package that contains my info
